from django.conf import settings


CONFIG_DEFAULTS = {
    "PROPS": {
        "mode": "tree",
        "mainMenuBar": True,
        "navigationBar": True,
        "statusBar": True,
        "askToFormat": True,
        "readOnly": False,
        "indentations": 4,
        "tabSize": 4,
        "escapeControlCharacters": False,
        "flattenColumns": True,
    }
}


def get_config():
    return {
        "PROPS": {
            **CONFIG_DEFAULTS["PROPS"],
            **getattr(settings, "SVELTE_JSONEDITOR", {}).get("PROPS", {}),
        }
    }



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class DjangoSvelteJsonEditorAppConfig(AppConfig):
    """Django application metadata and config"""

    name = "django_svelte_jsoneditor"
    label = "django_svelte_jsoneditor"
    verbose_name = _("Django Svelte JSONEditor")



import json
from django.forms import Textarea

from .settings import get_config


class SvelteJSONEditorWidget(Textarea):
    template_name = "django_svelte_jsoneditor/widgets/svelte_jsoneditor.html"

    def __init__(self, props=None, attrs=None):
        if attrs is None:
            attrs = {}

        self.props = {} if props is None else props.copy()
        attrs.update({"class": "hidden"})

        super().__init__(attrs)

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context["widget"].update({"props": json.dumps({**get_config()["PROPS"], **self.props})})
        return context

    class Media:
        css = {"all": ("django_svelte_jsoneditor/css/svelte_jsoneditor.css",)}
